@@ -16,7 +16,7 @@
   plotKML.env(show.env = FALSE, silent = TRUE)
   metadata.env()
   
-  packageStartupMessage(paste("URL:", get("home_url", envir = plotKML.opts)))
+  packageStartupMessage("URL: https://github.com/Envirometrix/plotKML/")
 
   return(invisible(0))
   	
